/*!
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
import Span from '../../trace/span/Span';
import Segment from '../../trace/context/Segment';
import { Component } from '../Component';
import { ContextCarrier } from './ContextCarrier';
export default interface Context {
    segment: Segment;
    nSpans: number;
    finished: boolean;
    newLocalSpan(operation: string, parent?: Span): Span;
    newEntrySpan(operation: string, carrier?: ContextCarrier, inherit?: Component | Component[]): Span;
    newExitSpan(operation: string, component: Component, inherit?: Component): Span;
    start(span: Span): Context;
    stop(span: Span): boolean;
    async(span: Span): void;
    resync(span: Span): void;
    /**
     * Returns the global trace id of the current trace, if there is no trace when invoking this method,
     * "N/A" is returned.
     */
    traceId(): string;
}
